@@ -1,5 +1,5 @@
-window.limit = 1000; // maximum number of parameters to cache
-window.time_limit = 100; // maximum seconds to cache parameters
+window.limit = 5000; // maximum number of parameters to cache
+window.time_limit = 60*60*24; // maximum seconds to cache parameters
 window.graphs = [];
 window.parameter_types = [];
 window.parameters = new Object();
@@ -38,7 +38,7 @@ ws.onmessage = function (evt) {
                     break;
                 case "histogram":
                     var new_graph = new Histogram();
-                    new_graph.nbins = graph.nbins;
+                    new_graph.set_nbins(graph.nbins);
                     break;
                 default:
                     log_message("Received invalid graph type '" + graph.type + "'");
